# Utils (WWW)

Utilities for accessing webpages

## Setup & Install

https://pypi.org/project/utils_www-nuuuwan/#history

```
pip install utils_www-nuuuwan
```

## Version History 

### 1.0.0 
* Base Version